import stamp.core.*;
import stamp.util.text.*;
import stamp.peripheral.web.*;

/**
  Pink test program for receiving udp messages
  Author: Peter Verkaik (peterverkaik@boselectro.nl)
  Date: 09 november 2005
*/

public class Pink_udpreceive_test {

  //Javelin pin assignments
  static final int pinRX = CPU.pin10;
  static final int pinTX = CPU.pin11;

  //Pink declarations
  static ScaledTimer16 pinkTimer = new ScaledTimer16(1000,100); //timeout is 1000 units, unit is 100*10uSec
  static Uart tx = new Uart(Uart.dirTransmit, pinTX, Uart.dontInvert, Uart.speed9600, Uart.stop1);
  static Uart rx = new Uart(Uart.dirReceive, pinRX, Uart.dontInvert, Uart.speed9600, Uart.stop1);
  static Pink myPink = new Pink('0',tx,rx,pinkTimer);

  //buffers
  static char[] buf = new char[65]; //last byte will be cleared by reading PINK varriables

  /*
     Read and print range of PINK variables plus status and post.
  */
  static void readAll(int start, int n) {
    int p,s;
    while (n > 0) {
      p = myPink.readVar(start,buf,32767,0);
      Format.printf("%03d: ",start);
      if (p < 0) { //timeout
        Format.printf("TIMEOUT\n");
      }
      else {
        Format.printf("(bytes=%02d) ",p);
        Format.printf("%s\n",buf);
      }
      start++;
      n--;
    }
    s = myPink.getStatus();
    Format.printf("Status: ");
    if (s < 0) { //timeout
      Format.printf("TIMEOUT\n");
    }
    else {
      Format.printf("%08b\n",s);
      if (myPink.isUpdated()) {
        p = myPink.getPost();
        Format.printf("      : ");
        if (p < 0) { //timeout
          Format.printf("POST TIMEOUT\n");
        }
        else {
          Format.printf("Var_%02d POST update\n",p);
          p = myPink.readVar(p,buf,32767,0);
          if (p < 0) { //timeout
            Format.printf("      : TIMEOUT\n");
          }
          else {
            Format.printf("      : %s\n",buf);
          }
        }
      }
//      if (myPink.isUdp()) {
//        Format.printf("      : received udp message\n");
        p = myPink.readVar(Pink.Nb_varBM,buf,32767,0);
//        Format.printf("      : ");
        if (p < 0) { //timeout
          Format.printf("UDP TIMEOUT\n");
        }
        else {
          Format.printf("Nb_varBM (bytes=%d) ",p);
          Format.printf("%s\n",buf);
        }
//      }
//      if (myPink.isConnected()) Format.printf("      : connected\n");
//      if (myPink.isReady())     Format.printf("      : ready\n");
//      if (myPink.isError())     Format.printf("      : error\n");
    }
  }

  static void main() {
    Format.printf("Pink udp receive test program\n");
    while (true) {
      readAll(0,0);
      CPU.delay(31500); //wait 3 seconds
      CPU.delay(31500); //wait 3 seconds
    }
  }

}